@@ -1,11 +1,16 @@
-import inspect
+"""Checker or use of forbidden imports.
+"""
 
 from astroid import nodes
 from pylint.checkers import BaseChecker
 from pylint.checkers.utils import only_required_for_messages
+from pylint.lint import PyLinter
 
 
 class ForbiddenImportChecker(BaseChecker):
+    """A checker class to report on the disallowed imports in the file.
+    Use options to specify the import modules that are allowed and the extra import modules."""
+
     name = "forbidden_import"
     msgs = {
         "E9999": (
@@ -35,11 +40,8 @@ class ForbiddenImportChecker(BaseChecker):
         ),
     )
 
-    # this is important so that your checker is executed before others
-    priority = -1
-
     @only_required_for_messages("forbidden-import")
-    def visit_import(self, node):
+    def visit_import(self, node: nodes.Import) -> None:
         """visit an Import node"""
         temp = [
             name
@@ -56,7 +58,7 @@ class ForbiddenImportChecker(BaseChecker):
             )
 
     @only_required_for_messages("forbidden-import")
-    def visit_importfrom(self, node):
+    def visit_importfrom(self, node: nodes.ImportFrom) -> None:
         """visit an ImportFrom node"""
         if (
             node.modname not in self.linter.config.allowed_import_modules
@@ -65,7 +67,7 @@ class ForbiddenImportChecker(BaseChecker):
             self.add_message("forbidden-import", node=node, args=(node.modname, node.lineno))
 
     @only_required_for_messages("forbidden-import")
-    def visit_call(self, node):
+    def visit_call(self, node: nodes.Call) -> None:
         if isinstance(node.func, nodes.Name):
             name = node.func.name
             # ignore the name if it's not a builtin (i.e. not defined in the
@@ -77,10 +79,9 @@ class ForbiddenImportChecker(BaseChecker):
                         and node.args[0].value not in self.linter.config.extra_imports
                     ):
                         args = (node.args[0].value, node.lineno)
-                        # add the message
                         self.add_message("forbidden-import", node=node, args=args)
 
 
-def register(linter):
-    """required method to auto register this checker"""
+def register(linter: PyLinter) -> None:
+    """Required method to auto register this checker"""
     linter.register_checker(ForbiddenImportChecker(linter))
