@@ -1,4 +1,4 @@
-"""A checker used for identifying names that don't conform to Python naming conventions."""
+"""Checker used for identifying names that don't conform to Python naming conventions."""
 
 import re
 from typing import List, Optional
@@ -9,6 +9,8 @@ from pylint.checkers.base.name_checker.checker import _redefines_import
 from pylint.checkers.utils import only_required_for_messages
 from pylint.lint import PyLinter
 
+from python_ta.utils import _is_in_main
+
 # Bad variable names.
 BAD_NAMES = {"l", "I", "O"}
 
@@ -277,10 +279,6 @@ class InvalidNameChecker(BaseChecker):
     """
 
     name = "naming_convention_violation"
-    # Template of displayed message will include the following:
-    #   1. Describe the variable name type (e.g. `module`, `const`, etc.) and the name itself.
-    #   2. Explanation of how the name violates the naming convention and suggest a
-    #   correction(s), if appropriate.
     msgs = {
         "C9103": (
             "%s",
@@ -294,9 +292,6 @@ class InvalidNameChecker(BaseChecker):
         ),
     }
 
-    # this is important so that your checker is executed before others
-    priority = -1
-
     @only_required_for_messages("module-name-violation")
     def visit_module(self, node: nodes.Module) -> None:
         """Visit a Module node to check for any name violations.
@@ -305,7 +300,7 @@ class InvalidNameChecker(BaseChecker):
         self._check_name("module", node.name.split(".")[-1], node)
 
     @only_required_for_messages("naming-convention-violation")
-    def visit_classdef(self, node: nodes.ClassDef):
+    def visit_classdef(self, node: nodes.ClassDef) -> None:
         """Visit a Class node to check for any name violations.
 
         Taken from pylint.checkers.base.name_checker.checker."""
@@ -325,7 +320,7 @@ class InvalidNameChecker(BaseChecker):
     visit_asyncfunctiondef = visit_functiondef
 
     @only_required_for_messages("naming-convention-violation")
-    def visit_assignname(self, node: nodes.AssignName):
+    def visit_assignname(self, node: nodes.AssignName) -> None:
         """Visit an AssignName node to check for any name violations.
 
         Taken from pylint.checkers.base.name_checker.checker."""
@@ -341,7 +336,7 @@ class InvalidNameChecker(BaseChecker):
             self._check_name("argument", node.name, node)
 
         # Check names defined in module scope
-        elif isinstance(frame, nodes.Module):
+        elif isinstance(frame, nodes.Module) and not _is_in_main(node):
             # Check names defined in Assign nodes
             if isinstance(assign_type, nodes.Assign):
                 inferred_assign_type = utils.safe_infer(assign_type.value)
@@ -456,17 +451,22 @@ class InvalidNameChecker(BaseChecker):
         Taken from pylint.checkers.base.name_checker.checker."""
         inferred = utils.safe_infer(node)
         if isinstance(inferred, nodes.ClassDef):
-            if inferred.qname() == ".Union":
+            qname = inferred.qname()
+            if qname == "typing.TypeAlias":
+                return True
+            if qname == ".Union":
                 # Union is a special case because it can be used as a type alias
                 # or as a type annotation. We only want to check the former.
                 assert node is not None
                 return not isinstance(node.parent, nodes.AnnAssign)
         elif isinstance(inferred, nodes.FunctionDef):
+            # TODO: when py3.12 is minimum, remove this condition
+            # TypeAlias became a class in python 3.12
             if inferred.qname() == "typing.TypeAlias":
                 return True
         return False
 
 
 def register(linter: PyLinter) -> None:
-    """Register this checker to the linter."""
+    """Required method to auto-register this checker to the linter"""
     linter.register_checker(InvalidNameChecker(linter))
