@@ -1,4 +1,4 @@
-"""checker for variables that might not be defined in the program.
+"""Checker for variables that might not be defined in the program.
 """
 from itertools import chain
 from typing import Generator, Set, Union
@@ -6,15 +6,16 @@ from typing import Generator, Set, Union
 from astroid import nodes
 from pylint.checkers import BaseChecker, utils
 from pylint.checkers.utils import only_required_for_messages
+from pylint.lint import PyLinter
 
 from python_ta.cfg.graph import CFGBlock, ControlFlowGraph
 
 
 class PossiblyUndefinedChecker(BaseChecker):
+    """A checker class that reports variables that have the possibility of being undefined when a statement
+    is executed"""
 
-    # name is the same as file name but without _checker part
     name = "possibly_undefined"
-    # use dashes for connecting words in message symbol
     msgs = {
         "E9969": (
             "This variable might not be defined when this statement is executed.",
@@ -23,24 +24,23 @@ class PossiblyUndefinedChecker(BaseChecker):
         )
     }
 
-    # this is important so that your checker is executed before others
-    priority = -1
-
-    def __init__(self, linter=None):
+    def __init__(self, linter=None) -> None:
         super().__init__(linter=linter)
         self._possibly_undefined: Set[nodes.Name] = set()
 
     @only_required_for_messages("possibly-undefined")
-    def visit_name(self, node):
+    def visit_name(self, node: nodes.Name) -> None:
         """Adds message if there exists a path from the start block to node where
         a variable used by node might not be defined."""
         if node in self._possibly_undefined:
             self.add_message("possibly-undefined", node=node)
 
-    def visit_module(self, node):
+    def visit_module(self, node: nodes.Module) -> None:
+        """Visits the module node"""
         self._analyze(node)
 
-    def visit_functiondef(self, node):
+    def visit_functiondef(self, node: nodes.FunctionDef) -> None:
+        """Visits the function definition"""
         self._analyze(node)
 
     def _analyze(self, node: Union[nodes.Module, nodes.FunctionDef]) -> None:
@@ -142,11 +142,12 @@ class PossiblyUndefinedChecker(BaseChecker):
                 yield from self.get_nodes(statement.value)
             else:
                 yield from self.get_nodes(statement.elt)
-        else:
-            yield from statement.nodes_of_class(
-                (nodes.AssignName, nodes.DelName, nodes.Name), nodes.FunctionDef
-            )
+        elif isinstance(statement, (nodes.AssignName, nodes.DelName, nodes.Name)):
+            yield statement
+        elif not isinstance(statement, nodes.FunctionDef):
+            yield from multiple_nodes(statement.get_children())
 
 
-def register(linter):
+def register(linter: PyLinter) -> None:
+    """Required method to auto-register this checker to the linter"""
     linter.register_checker(PossiblyUndefinedChecker(linter))
