@@ -1,8 +1,17 @@
+"""Checker for the style of the file"""
+from typing import List, Tuple
+
 import pycodestyle
+from astroid import nodes
 from pylint.checkers import BaseRawFileChecker
+from pylint.lint import PyLinter
 
 
 class PycodestyleChecker(BaseRawFileChecker):
+    """A checker class to report PEP8 style errors in the file.
+
+    Use options to specify the list of PEP8 errors to ignore"""
+
     name = "pep8_errors"
     msgs = {"E9989": ("Found pycodestyle (PEP8) style error at %s", "pep8-errors", "")}
 
@@ -18,10 +27,7 @@ class PycodestyleChecker(BaseRawFileChecker):
         ),
     )
 
-    # this is important so that your checker is executed before others
-    priority = -1
-
-    def process_module(self, node):
+    def process_module(self, node: nodes.NodeNG) -> None:
         style_guide = pycodestyle.StyleGuide(
             paths=[node.stream().name],
             reporter=JSONReport,
@@ -34,7 +40,7 @@ class PycodestyleChecker(BaseRawFileChecker):
 
 
 class JSONReport(pycodestyle.StandardReport):
-    def get_file_results(self):
+    def get_file_results(self) -> List[Tuple]:
         self._deferred_print.sort()
         return [
             (line_number, f"line {line_number}, column {offset}: {text}")
@@ -42,6 +48,6 @@ class JSONReport(pycodestyle.StandardReport):
         ]
 
 
-def register(linter):
-    """required method to auto register this checker"""
+def register(linter: PyLinter) -> None:
+    """Required method to auto-register this checker to the linter"""
     linter.register_checker(PycodestyleChecker(linter))
